@@ -2,17 +2,7 @@
 #
 # Copyright 2016 Hewlett-Packard Development Company, L.P.
 #
-# Licensed under the Apache License, Version 2.0 (the "License"); you may
-# not use this file except in compliance with the License. You may obtain
-# a copy of the License at
-#
-#      http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-# License for the specific language governing permissions and limitations
-# under the License.
+# SPDX-License-Identifier: Apache-2.0
 
 r"""
 ======================================================
@@ -24,7 +14,7 @@ possible security implications. The following blacklist tests are run against
 any import statements or calls encountered in the scanned code base.
 
 Note that the XML rules listed here are mostly based off of Christian Heimes'
-work on defusedxml: https://pypi.python.org/pypi/defusedxml
+work on defusedxml: https://pypi.org/project/defusedxml/
 
 B401: import_telnetlib
 ----------------------
@@ -46,7 +36,7 @@ SSH/SFTP/SCP or some other encrypted protocol.
 +------+---------------------+------------------------------------+-----------+
 | ID   |  Name               |  Imports                           |  Severity |
 +======+=====================+====================================+===========+
-| B402 | inport_ftplib       | - ftplib                           | high      |
+| B402 | import_ftplib       | - ftplib                           | high      |
 +------+---------------------+------------------------------------+-----------+
 
 B403: import_pickle
@@ -59,6 +49,8 @@ Consider possible security implications associated with these modules.
 +======+=====================+====================================+===========+
 | B403 | import_pickle       | - pickle                           | low       |
 |      |                     | - cPickle                          |           |
+|      |                     | - dill                             |           |
+|      |                     | - shelve                           |           |
 +------+---------------------+------------------------------------+-----------+
 
 B404: import_subprocess
@@ -179,6 +171,49 @@ at https://httpoxy.org/.
 |      |                     | - twisted.web.twcgi.CGIScript      |           |
 +------+---------------------+------------------------------------+-----------+
 
+B413: import_pycrypto
+---------------------
+pycrypto library is known to have publicly disclosed buffer overflow
+vulnerability https://github.com/dlitz/pycrypto/issues/176. It is no longer
+actively maintained and has been deprecated in favor of pyca/cryptography
+library.
+
++------+---------------------+------------------------------------+-----------+
+| ID   |  Name               |  Imports                           |  Severity |
++======+=====================+====================================+===========+
+| B413 | import_pycrypto     | - Crypto.Cipher                    | high      |
+|      |                     | - Crypto.Hash                      |           |
+|      |                     | - Crypto.IO                        |           |
+|      |                     | - Crypto.Protocol                  |           |
+|      |                     | - Crypto.PublicKey                 |           |
+|      |                     | - Crypto.Random                    |           |
+|      |                     | - Crypto.Signature                 |           |
+|      |                     | - Crypto.Util                      |           |
++------+---------------------+------------------------------------+-----------+
+
+B414: import_pycryptodome
+-------------------------
+This import blacklist has been removed. The information here has been
+left for historical purposes.
+
+pycryptodome is a direct fork of pycrypto that has not fully addressed
+the issues inherent in PyCrypto.  It seems to exist, mainly, as an API
+compatible continuation of pycrypto and should be deprecated in favor
+of pyca/cryptography which has more support among the Python community.
+
++------+---------------------+------------------------------------+-----------+
+| ID   |  Name               |  Imports                           |  Severity |
++======+=====================+====================================+===========+
+| B414 | import_pycryptodome | - Cryptodome.Cipher                | high      |
+|      |                     | - Cryptodome.Hash                  |           |
+|      |                     | - Cryptodome.IO                    |           |
+|      |                     | - Cryptodome.Protocol              |           |
+|      |                     | - Cryptodome.PublicKey             |           |
+|      |                     | - Cryptodome.Random                |           |
+|      |                     | - Cryptodome.Signature             |           |
+|      |                     | - Cryptodome.Util                  |           |
++------+---------------------+------------------------------------+-----------+
+
 """
 
 from bandit.blacklists import utils
@@ -212,7 +247,7 @@ def gen_blacklist():
         ))
 
     sets.append(utils.build_conf_dict(
-        'import_pickle', 'B403', ['pickle', 'cPickle'],
+        'import_pickle', 'B403', ['pickle', 'cPickle', 'dill', 'shelve'],
         'Consider possible security implications associated with '
         '{name} module.', 'LOW'
         ))
@@ -224,7 +259,7 @@ def gen_blacklist():
         ))
 
     # Most of this is based off of Christian Heimes' work on defusedxml:
-    #   https://pypi.python.org/pypi/defusedxml/#defusedxml-sax
+    #   https://pypi.org/project/defusedxml/#defusedxml-sax
 
     xml_msg = ('Using {name} to parse untrusted XML data is known to be '
                'vulnerable to XML attacks. Replace {name} with the equivalent '
@@ -268,4 +303,18 @@ def gen_blacklist():
         '{name} module.', 'HIGH'
         ))
 
+    sets.append(utils.build_conf_dict(
+        'import_pycrypto', 'B413',
+        ['Crypto.Cipher',
+         'Crypto.Hash',
+         'Crypto.IO',
+         'Crypto.Protocol',
+         'Crypto.PublicKey',
+         'Crypto.Random',
+         'Crypto.Signature',
+         'Crypto.Util'],
+        'The pyCrypto library and its module {name} are no longer actively '
+        'maintained and have been deprecated. '
+        'Consider using pyca/cryptography library.', 'HIGH'))
+
     return {'Import': sets, 'ImportFrom': sets, 'Call': sets}
