@@ -1,16 +1,6 @@
 # -*- coding:utf-8 -*-
 #
-# Licensed under the Apache License, Version 2.0 (the "License"); you may
-# not use this file except in compliance with the License. You may obtain
-# a copy of the License at
-#
-#      http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-# License for the specific language governing permissions and limitations
-# under the License.
+# SPDX-License-Identifier: Apache-2.0
 
 r"""
 =============
@@ -24,13 +14,16 @@ This formatter outputs the issues in a comma separated values format.
 .. code-block:: none
 
     filename,test_name,test_id,issue_severity,issue_confidence,issue_text,
-    line_number,line_range
+    line_number,line_range,more_info
     examples/yaml_load.py,blacklist_calls,B301,MEDIUM,HIGH,"Use of unsafe yaml
     load. Allows instantiation of arbitrary objects. Consider yaml.safe_load().
-    ",5,[5]
+    ",5,[5],https://bandit.readthedocs.io/en/latest/
 
 .. versionadded:: 0.11.0
 
+.. versionchanged:: 1.5.0
+    New field `more_info` added to output
+
 """
 # Necessary for this formatter to work when imported on Python 2. Importing
 # the standard library's csv module conflicts with the name of this module.
@@ -40,6 +33,8 @@ import csv
 import logging
 import sys
 
+from bandit.core import docs_utils
+
 LOG = logging.getLogger(__name__)
 
 
@@ -64,13 +59,16 @@ def report(manager, fileobj, sev_level, conf_level, lines=-1):
                       'issue_confidence',
                       'issue_text',
                       'line_number',
-                      'line_range']
+                      'line_range',
+                      'more_info']
 
         writer = csv.DictWriter(fileobj, fieldnames=fieldnames,
                                 extrasaction='ignore')
         writer.writeheader()
         for result in results:
-            writer.writerow(result.as_dict(with_code=False))
+            r = result.as_dict(with_code=False)
+            r['more_info'] = docs_utils.get_url(r['test_id'])
+            writer.writerow(r)
 
     if fileobj.name != sys.stdout.name:
         LOG.info("CSV output written to file: %s", fileobj.name)
