@@ -2,46 +2,26 @@
 #
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
-# Licensed under the Apache License, Version 2.0 (the "License"); you may
-# not use this file except in compliance with the License. You may obtain
-# a copy of the License at
-#
-#      http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-# License for the specific language governing permissions and limitations
-# under the License.
+# SPDX-License-Identifier: Apache-2.0
 
 import ast
 import re
 
+import six
+
 import bandit
 from bandit.core import test_properties as test
 
-
-def _has_special_characters(command):
-    # check if it contains any of the characters that may cause globing,
-    # multiple commands, subshell, or variable resolution
-    # glob: [ { * ?
-    # variable: $
-    # subshell: ` $
-    return bool(re.search(r'[{|\[;$\*\?`]', command))
+# yuck, regex: starts with a windows drive letter (eg C:)
+# or one of our path delimeter characters (/, \, .)
+full_path_match = re.compile(r'^(?:[A-Za-z](?=\:)|[\\\/\.])')
 
 
 def _evaluate_shell_call(context):
     no_formatting = isinstance(context.node.args[0], ast.Str)
-    if no_formatting:
-        command = context.call_args[0]
-        no_special_chars = not _has_special_characters(command)
-    else:
-        no_special_chars = False
 
-    if no_formatting and no_special_chars:
+    if no_formatting:
         return bandit.LOW
-    elif no_formatting:
-        return bandit.MEDIUM
     else:
         return bandit.HIGH
 
@@ -56,8 +36,7 @@ def gen_config(name):
              'subprocess.call',
              'subprocess.check_call',
              'subprocess.check_output',
-             'utils.execute',
-             'utils.execute_with_timeout'],
+             'subprocess.run'],
 
             # Start a process with a function vulnerable to shell injection.
             'shell':
@@ -97,6 +76,28 @@ def gen_config(name):
             }
 
 
+def has_shell(context):
+    keywords = context.node.keywords
+    result = False
+    if 'shell' in context.call_keywords:
+        for key in keywords:
+            if key.arg == 'shell':
+                val = key.value
+                if isinstance(val, ast.Num):
+                    result = bool(val.n)
+                elif isinstance(val, ast.List):
+                    result = bool(val.elts)
+                elif isinstance(val, ast.Dict):
+                    result = bool(val.keys)
+                elif isinstance(val, ast.Name) and val.id in ['False', 'None']:
+                    result = False
+                elif not six.PY2 and isinstance(val, ast.NameConstant):
+                    result = val.value
+                else:
+                    result = True
+    return result
+
+
 @test.takes_config('shell_injection')
 @test.checks('Call')
 @test.test_id('B602')
@@ -185,14 +186,14 @@ def subprocess_popen_with_shell_equals_true(context, config):
     .. seealso::
 
      - https://security.openstack.org
-     - https://docs.python.org/2/library/subprocess.html#frequently-used-arguments  # noqa
+     - https://docs.python.org/3/library/subprocess.html#frequently-used-arguments
      - https://security.openstack.org/guidelines/dg_use-subprocess-securely.html
      - https://security.openstack.org/guidelines/dg_avoid-shell-true.html
 
     .. versionadded:: 0.9.0
-    """
+    """  # noqa: E501
     if config and context.call_function_name_qual in config['subprocess']:
-        if context.check_call_arg_value('shell', 'True'):
+        if has_shell(context):
             if len(context.call_args) > 0:
                 sev = _evaluate_shell_call(context)
                 if sev == bandit.LOW:
@@ -204,15 +205,6 @@ def subprocess_popen_with_shell_equals_true(context, config):
                              'rewriting without shell',
                         lineno=context.get_lineno_for_call_arg('shell'),
                     )
-                elif sev == bandit.MEDIUM:
-                    return bandit.Issue(
-                        severity=bandit.MEDIUM,
-                        confidence=bandit.HIGH,
-                        text='call with shell=True contains special shell '
-                             'characters, consider moving extra logic into '
-                             'Python code',
-                        lineno=context.get_lineno_for_call_arg('shell'),
-                    )
                 else:
                     return bandit.Issue(
                         severity=bandit.HIGH,
@@ -227,7 +219,7 @@ def subprocess_popen_with_shell_equals_true(context, config):
 @test.checks('Call')
 @test.test_id('B603')
 def subprocess_without_shell_equals_true(context, config):
-    """**B603: Test for use of subprocess with shell equals true**
+    """**B603: Test for use of subprocess without shell equals true**
 
     Python possesses many mechanisms to invoke an external executable. However,
     doing so may present a security issue if appropriate care is not taken to
@@ -285,14 +277,14 @@ def subprocess_without_shell_equals_true(context, config):
     .. seealso::
 
      - https://security.openstack.org
-     - https://docs.python.org/2/library/subprocess.html#frequently-used-arguments  # noqa
+     - https://docs.python.org/3/library/subprocess.html#frequently-used-arguments
      - https://security.openstack.org/guidelines/dg_avoid-shell-true.html
      - https://security.openstack.org/guidelines/dg_use-subprocess-securely.html
 
     .. versionadded:: 0.9.0
-    """
+    """  # noqa: E501
     if config and context.call_function_name_qual in config['subprocess']:
-        if not context.check_call_arg_value('shell', 'True'):
+        if not has_shell(context):
             return bandit.Issue(
                 severity=bandit.LOW,
                 confidence=bandit.HIGH,
@@ -346,8 +338,8 @@ def any_other_function_with_shell_equals_true(context, config):
             # Start a process using the subprocess module, or one of its
             wrappers.
             subprocess: [subprocess.Popen, subprocess.call,
-                         subprocess.check_call, subprocess.check_output,
-                         utils.execute, utils.execute_with_timeout]
+                         subprocess.check_call, subprocess.check_output
+                         execute_with_timeout]
 
 
     :Example:
@@ -365,16 +357,16 @@ def any_other_function_with_shell_equals_true(context, config):
     .. seealso::
 
      - https://security.openstack.org/guidelines/dg_avoid-shell-true.html
-     - https://security.openstack.org/guidelines/dg_use-subprocess-securely.html  # noqa
+     - https://security.openstack.org/guidelines/dg_use-subprocess-securely.html
 
     .. versionadded:: 0.9.0
-    """
+    """  # noqa: E501
     if config and context.call_function_name_qual not in config['subprocess']:
-        if context.check_call_arg_value('shell', 'True'):
+        if has_shell(context):
             return bandit.Issue(
                 severity=bandit.MEDIUM,
                 confidence=bandit.LOW,
-                text='Function call with shell=True parameter identifed, '
+                text='Function call with shell=True parameter identified, '
                      'possible security issue.',
                 lineno=context.get_lineno_for_call_arg('shell'),
                 )
@@ -396,7 +388,7 @@ def start_process_with_a_shell(context, config):
     invocation is dangerous as it is vulnerable to various shell injection
     attacks. Great care should be taken to sanitize all input in order to
     mitigate this risk. Calls of this type are identified by the use of certain
-    commands which are known to use shells. Bandit will report a MEDIUM
+    commands which are known to use shells. Bandit will report a LOW
     severity warning.
 
     See also:
@@ -439,7 +431,7 @@ def start_process_with_a_shell(context, config):
     .. code-block:: none
 
         >> Issue: Starting a process with a shell: check for injection.
-           Severity: Medium   Confidence: Medium
+           Severity: Low   Confidence: Medium
            Location: examples/os_system.py:3
         2
         3   os.system('/bin/echo hi')
@@ -447,12 +439,12 @@ def start_process_with_a_shell(context, config):
     .. seealso::
 
      - https://security.openstack.org
-     - https://docs.python.org/2/library/os.html#os.system
-     - https://docs.python.org/2/library/subprocess.html#frequently-used-arguments  # noqa
+     - https://docs.python.org/3/library/os.html#os.system
+     - https://docs.python.org/3/library/subprocess.html#frequently-used-arguments
      - https://security.openstack.org/guidelines/dg_use-subprocess-securely.html
 
     .. versionadded:: 0.10.0
-    """
+    """  # noqa: E501
     if config and context.call_function_name_qual in config['shell']:
         if len(context.call_args) > 0:
             sev = _evaluate_shell_call(context)
@@ -464,14 +456,6 @@ def start_process_with_a_shell(context, config):
                          'Seems safe, but may be changed in the future, '
                          'consider rewriting without shell'
                 )
-            elif sev == bandit.MEDIUM:
-                return bandit.Issue(
-                    severity=bandit.MEDIUM,
-                    confidence=bandit.HIGH,
-                    text='Starting a process with a shell and special shell '
-                         'characters, consider moving extra logic into '
-                         'Python code'
-                )
             else:
                 return bandit.Issue(
                     severity=bandit.HIGH,
@@ -553,12 +537,12 @@ def start_process_with_no_shell(context, config):
     .. seealso::
 
      - https://security.openstack.org
-     - https://docs.python.org/2/library/os.html#os.system
-     - https://docs.python.org/2/library/subprocess.html#frequently-used-arguments  # noqa
+     - https://docs.python.org/3/library/os.html#os.system
+     - https://docs.python.org/3/library/subprocess.html#frequently-used-arguments
      - https://security.openstack.org/guidelines/dg_use-subprocess-securely.html
 
     .. versionadded:: 0.10.0
-    """
+    """  # noqa: E501
 
     if config and context.call_function_name_qual in config['no_shell']:
         return bandit.Issue(
@@ -639,7 +623,7 @@ def start_process_with_partial_path(context, config):
     .. seealso::
 
      - https://security.openstack.org
-     - https://docs.python.org/2/library/os.html#process-management
+     - https://docs.python.org/3/library/os.html#process-management
 
     .. versionadded:: 0.13.0
     """
@@ -649,14 +633,13 @@ def start_process_with_partial_path(context, config):
            context.call_function_name_qual in config['shell'] or
            context.call_function_name_qual in config['no_shell']):
 
-            delims = ['/', '\\', '.']
             node = context.node.args[0]
             # some calls take an arg list, check the first part
             if isinstance(node, ast.List):
                 node = node.elts[0]
 
             # make sure the param is a string literal and not a var name
-            if(isinstance(node, ast.Str) and node.s[0] not in delims):
+            if isinstance(node, ast.Str) and not full_path_match.match(node.s):
                 return bandit.Issue(
                     severity=bandit.LOW,
                     confidence=bandit.HIGH,
